@@ -9,6 +9,7 @@ import datetime
 import json
 import logging
 import os
+import re
 import subprocess
 import sys
 import time
@@ -39,6 +40,8 @@ def universalizeDateTime( dt ):
 
 def checkInstanceClocks( liveInstances, dataDirPath ):
     jlogFilePath = dataDirPath + '/checkInstanceClocks.jlog'
+    allIids = [inst['instanceId'] for inst in liveInstances ]
+    unfoundIids = set( allIids )
     cmd = "date --iso-8601=seconds"
     # check for a running geth process on each instance
     stepStatuses = tellInstances.tellInstances( liveInstances, cmd,
@@ -55,17 +58,29 @@ def checkInstanceClocks( liveInstances, dataDirPath ):
     with open( jlogFilePath, 'rb' ) as inFile:
         for line in inFile:
             decoded = json.loads( line )
-            if 'stdout' in decoded:
+            iid = decoded['instanceId']
+            if decoded.get( 'stdout' ):
                 #logger.info( decoded )
                 masterDateTime = dateutil.parser.parse( decoded['dateTime'] )
-                nodeDateTime = dateutil.parser.parse( decoded['stdout'] )
-                delta = masterDateTime - nodeDateTime
-                discrep =delta.total_seconds()
-                logger.info( 'discrep: %.1f seconds on inst %s',
-                    discrep, decoded['instanceId'] )
-                if discrep > 4 or discrep < -1:
-                    logger.warning( 'bad time discrep: %.1f', discrep )
-                    errorsByIid[ decoded['instanceId'] ] = {'discrep': discrep }
+                try:
+                    nodeDateTime = dateutil.parser.parse( decoded['stdout'] )
+                except Exception as exc:
+                    logger.warning( 'exception parsing %s', decoded['stdout'] )
+                    errorsByIid[ iid ] = {'exception': exc }
+                else:
+                    unfoundIids.discard( iid )
+                    delta = masterDateTime - nodeDateTime
+                    discrep =delta.total_seconds()
+                    logger.info( 'discrep: %.1f seconds on inst %s',
+                        discrep, iid )
+                    if discrep > 4 or discrep < -1:
+                        logger.warning( 'bad time discrep: %.1f', discrep )
+                        errorsByIid[ iid ] = {'discrep': discrep }
+    if unfoundIids:
+        logger.warning( 'unfoundIids: %s', unfoundIids )
+        for iid in list( unfoundIids ):
+            if iid not in errorsByIid:
+                errorsByIid[ iid ] = {'found': False }
     logger.info( '%d errorsByIid: %s', len(errorsByIid), errorsByIid )
     return errorsByIid
 
@@ -136,6 +151,7 @@ def checkLogs( liveInstances, dataDirPath ):
             '''
             connected = False
             sealed = False
+            latestSealLine = None
             with open( logFilePath ) as logFile:
                 for line in logFile:
                     line = line.rstrip()
@@ -143,7 +159,7 @@ def checkLogs( liveInstances, dataDirPath ):
                         continue
                     if 'ERROR' in line:
                         if 'Ethereum peer removal failed' in line:
-                            logger.info( 'ignoring "peer removal failed"')
+                            logger.debug( 'ignoring "peer removal failed" for %s', iidAbbrev )
                             continue
                         logger.info( '%s: %s', iidAbbrev, line )
                         theseErrors = errorsByIid.get( iid, [] )
@@ -153,10 +169,19 @@ def checkLogs( liveInstances, dataDirPath ):
                         connected = True
                     elif 'Successfully sealed' in line:
                         sealed = True
+                        latestSealLine = line
                 if not connected:
                     logger.warning( 'instance %s did not initialize fully', iidAbbrev )
                 if sealed:
-                    logger.info( 'instance %s has successfully sealed', iidAbbrev )
+                    #logger.info( 'instance %s has successfully sealed', iidAbbrev )
+                    logger.debug( '%s latestSealLine: %s', iidAbbrev, latestSealLine )
+                    pat = r'\[(.*\|.*)\]'
+                    dateStr = re.search( pat, latestSealLine ).group(1)
+                    if dateStr:
+                        dateStr = dateStr.replace( '|', ' ' )
+                        latestSealDateTime = dateutil.parser.parse( dateStr )
+                        logger.info( 'latestSealDateTime: %s', latestSealDateTime.isoformat() )
+
     logger.info( 'found errors for %d instance(s)', len(errorsByIid) )
     #print( 'errorsByIid', errorsByIid  )
     summaryCsvFilePath = os.path.join( dataDirPath, 'errorSummary.csv' )
@@ -218,11 +243,12 @@ if __name__ == "__main__":
     #ap.add_argument( '--gethVersion', default ='1.9.25', help='version of geth' )
     ap.add_argument( '--configName', default ='priv_2', help='version of geth' )
     ap.add_argument( '--logLevel', default ='info', help='verbosity of log (e.g. debug, info, warning, error)' )
+    ap.add_argument( '--maxNewAuths', type=int, default=0, help='maximum nmber of new authorized signers (default 0)' )
     args = ap.parse_args()
 
     logLevel = ncsgeth.parseLogLevel( args.logLevel )
     logger.setLevel(logLevel)
-    tellInstances.logger.setLevel( logLevel )
+    tellInstances.logger.setLevel( logging.WARNING )  # logLevel
     logger.debug('the logger is configured')
 
     dataDirPath = args.dataDirPath
@@ -233,6 +259,8 @@ if __name__ == "__main__":
 
     anchorNodesFilePath = args.anchorNodes
 
+    maxNewAuths = args.maxNewAuths
+
     if not anchorNodesFilePath:
         logger.error( 'no anchorNodes given')
         sys.exit(1)
@@ -370,12 +398,13 @@ if __name__ == "__main__":
             terminatedIids.append( iid )
 
     # authorize good instances that have been up for long enough
+    #TODO skip this if maxNewAuths <= 0 
     trustedThresh = 12  # hours
-    maxNewAuths = 0
     nNewAuths = 0
     sleepAmt = 15
     if badIids:
         sleepAmt = 90  # longer to avoid possible trouble
+    authorizers = findAuthorizers( anchorInstances+liveInstances, savedSigners, badIids )
     now = datetime.datetime.now( datetime.timezone.utc )
     for inst in goodInstances:
         # limit the loop to <= maxNewAuths auths per run
@@ -393,7 +422,6 @@ if __name__ == "__main__":
             if not wasSigner:
                 results = ncsgeth.collectPrimaryAccounts( [inst], configName )
                 if results[0]:
-                    authorizers = findAuthorizers( anchorInstances+liveInstances, savedSigners, badIids )
                     logger.info( '%d authorizers', len(authorizers) )
                     if not authorizers:
                         break
@@ -407,9 +435,11 @@ if __name__ == "__main__":
                     minerResults = ncsgeth.startMiners( [inst], configName )
                     logger.info( 'authorizing %s account %s', iid[0:16], primaryAccount )
                     authResults = ncsgeth.authorizeSigner( authorizers, configName, primaryAccount, True )
-                    logger.info( 'authResults:  %s', authResults )
-                    waitForAuth( primaryAccount, True, authorizers, configName, timeLimit=15*60 )
-                    nNewAuths += 1
+                    #logger.info( 'authResults:  %s', authResults )
+                    good = waitForAuth( primaryAccount, True, authorizers, configName, timeLimit=15*60 )
+                    if good:
+                        authorizers.append( inst )
+                        nNewAuths += 1
 
     terminatedIids = set( terminatedIids )
     stillLive = [inst for inst in liveInstances if inst['instanceId'] not in terminatedIids]
